@@ -6,8 +6,6 @@
 #' @param template A Raster* or Spatial* object to serve 
 #' as a template for cropping.
 #' @param label A character string naming the study area.
-#' @param res A character string defining the resolution of the NHD to download.
-#' Either "medium" (the default), or "high".
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing. Defaults to "./RAW/NHD/".
 #' @param extraction.dir A character string indicating where the extracted and cropped NHD shapefiles should be put.
@@ -35,7 +33,7 @@
 #' plot(NHD$NHDArea, col='black', add=T)
 #' plot(NHD$NHDWaterbody, col='black', add=T)
 #' }
-get_nhd <- function(template, label, res='medium', raw.dir="./RAW/NHD/", extraction.dir="./EXTRACTIONS/NHD/", force.redo=FALSE){
+get_nhd <- function(template, label, raw.dir="./RAW/NHD/", extraction.dir="./EXTRACTIONS/NHD/", force.redo=FALSE){
   
   vectors.dir <- paste(extraction.dir,"/",label,"/spatial",sep='')
   
@@ -69,7 +67,7 @@ get_nhd <- function(template, label, res='medium', raw.dir="./RAW/NHD/", extract
   # Get the spatial data for each area
   message("(Down)Loading the NHD subregion data.")
   subregionShapes <- lapply(area.list, function(area){
-    return(get_nhd_subregion(template=template, area=area, res=res, raw.dir=raw.dir))
+    return(get_nhd_subregion(template=template, area=area, raw.dir=raw.dir))
   })
   
   # Get all layer names
@@ -160,19 +158,14 @@ get_huc4 <- function(template=NULL, raw.dir){
 #' \code{download_nhd_subregion} returns the path to the downloaded zip file.
 #'
 #' @param area A 4-character string indicating the HUC4 NHD subregion to download.
-#' @param res A character string defining the resolution of the NHD to download.
-#' Either "medium" (the default), or "high".
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing.
 #' @return A character string representing the full local path of the downloaded zip file.
 #' @export
 #' @keywords internal
-download_nhd_subregion <- function(area, res, raw.dir){
-  if(res=="medium"){
-    url <- paste('ftp://nhdftp.usgs.gov/DataSets/Staged/SubRegions/FileGDB/MediumResolution/NHDM',area,'_931v220.zip',sep='')
-  }else{
-    url <- paste('ftp://nhdftp.usgs.gov/DataSets/Staged/SubRegions/FileGDB/HighResolution/NHDH',area,'_931v220.zip',sep='')
-  }
+download_nhd_subregion <- function(area, raw.dir){
+
+  url <- paste('ftp://rockyftp.cr.usgs.gov/vdelivery/Datasets/Staged/Hydrography/NHD/HU4/HighResolution/GDB/NHD_H_',area,'_GDB.zip',sep='')
   
   destdir <- raw.dir
   download_data(url=url, destdir=destdir)
@@ -189,20 +182,18 @@ download_nhd_subregion <- function(area, res, raw.dir){
 #' @param template A Raster* or Spatial* object to serve 
 #' as a template for cropping.
 #' @param area A 4-character string indicating the HUC4 NHD subregion to download and crop.
-#' @param res A character string defining the resolution of the NHD to download.
-#' Either "medium" (the default), or "high".
 #' @param raw.dir A character string indicating where raw downloaded files should be put.
 #' The directory will be created if missing.
 #' @return A \code{SpatialPolygonsDataFrame} of the HUC4 regions within
 #' the specified \code{template}.
 #' @export
 #' @keywords internal
-get_nhd_subregion <- function(template=NULL, area, res, raw.dir){
+get_nhd_subregion <- function(template=NULL, area, raw.dir){
   tmpdir <- tempfile()
   if (!dir.create(tmpdir))
     stop("failed to create my temporary directory")
   
-  file <- download_nhd_subregion(area=area, res=res, raw.dir=raw.dir)
+  file <- download_nhd_subregion(area=area, raw.dir=raw.dir)
   
   utils::unzip(file,exdir=tmpdir)
   
